Exception: Rijn::AuthenticationError
- Inherits:
-
StandardError
- Object
- StandardError
- Rijn::AuthenticationError
- Defined in:
- lib/rijn/errors.rb
Overview
Raised when an encrypted value cannot be authenticated during decryption.
Raised when an encrypted value cannot be authenticated during decryption.